@@ -30,10 +30,6 @@ from PIL import ImageFont
 from .query_integral_image import query_integral_image
 from .tokenization import unigrams_and_bigrams, process_tokens
 
-FILE = os.path.dirname(__file__)
-FONT_PATH = os.environ.get('FONT_PATH', os.path.join(FILE, 'DroidSansMono.ttf'))
-STOPWORDS = set(map(str.strip, open(os.path.join(FILE, 'stopwords')).readlines()))
-
 
 class IntegralOccupancyMap(object):
     def __init__(self, height, width, mask):
@@ -314,10 +310,10 @@ class WordCloud(object):
                  contour_color='black', repeat=False,
                  include_numbers=False, min_word_length=0, collocation_threshold=30):
 
-        print("You are using the custom version yippie! This text changed time to parteeey!")
+        print("You are using a custom version of Muellers Wordcloud Generator. Custom version number: 0.6")
         
         if font_path is None:
-            font_path = FONT_PATH
+            print("Font Path need to be specified")
         if color_func is None and colormap is None:
             version = matplotlib.__version__
             if version[0] < "2" and version[2] < "5":
@@ -337,7 +333,7 @@ class WordCloud(object):
         self.scale = scale
         self.color_func = color_func or colormap_color_func(colormap)
         self.max_words = max_words
-        self.stopwords = stopwords if stopwords is not None else STOPWORDS
+        self.stopwords = stopwords
         self.min_font_size = min_font_size
         self.font_step = font_step
         self.regexp = regexp
